@@ -4,6 +4,7 @@ from .iter import Iterator, Range
 __all__ = [
     'infix',
     'is_a',
+    'as_a',
     'to',
     'step',
     'INF',
@@ -26,29 +27,26 @@ class infix(partial):
 is_a = infix(isinstance)
 has = infix(hasattr)
 
+@infix
+def as_a(obj, clazz):
+    return clazz(obj)
+
 @infix
 def to(start, end):
     return Iterator(Range(start, end))
 
 @infix
 def step(obj, step):
-    # ex. -2 step -> 2 step
     step = abs(step)
     obj = Iterator(obj) if not obj /is_a/ Iterator else obj
     return obj.slice(step=step)
 
 @infix
 def take(obj, n):
-    # ex. n = 3
-    # [0, 1, 2, 3, 4, 5, 6] =>
-    # [0, 1, 2]
     obj = Iterator(obj) if not obj /is_a/ Iterator else obj
     return obj.slice(stop=n)
 
 @infix
 def drop(obj, n):
-    # ex. n = 3
-    # [0, 1, 2, 3, 4, 5, 6] =>
-    # [3, 4, 5, 6]
     obj = Iterator(obj) if not obj /is_a/ Iterator else obj
     return obj.slice(start=n)
